@@ -18,14 +18,7 @@ macro_rules! old_and_new {
     }};
 }
 
-/// Network interfaces.
-///
-/// ```no_run
-/// use sysinfo::{NetworksExt, System, SystemExt};
-///
-/// let s = System::new_all();
-/// let networks = s.networks();
-/// ```
+#[doc = include_str!("../../md_doc/networks.md")]
 pub struct Networks {
     interfaces: HashMap<String, NetworkData>,
 }
@@ -38,6 +31,7 @@ impl Networks {
     }
 
     #[allow(clippy::cast_ptr_alignment)]
+    #[allow(clippy::uninit_vec)]
     fn update_networks(&mut self) {
         let mib = &mut [CTL_NET, PF_ROUTE, 0, 0, NET_RT_IFLIST2, 0];
         let mut len = 0;
@@ -174,7 +168,7 @@ impl NetworksExt for Networks {
     }
 }
 
-/// Contains network information.
+#[doc = include_str!("../../md_doc/network_data.md")]
 #[derive(PartialEq, Eq)]
 pub struct NetworkData {
     current_in: u64,
