@@ -11,13 +11,7 @@ use std::fs::{metadata, read_dir, File};
 use std::io::Read;
 use std::path::{Path, PathBuf};
 
-/// More information can be found at [kernel.org][k].
-///
-/// Note: these may not be present on virtual Linux systems, such as **Docker**
-/// or **Windows Subsystem for Linux**. These hosts do not expose this information
-/// and therefore `Component` elements may be missing or not as expected.
-///
-/// [k]: https://www.kernel.org/doc/Documentation/hwmon/sysfs-interface
+#[doc = include_str!("../../md_doc/component.md")]
 pub struct Component {
     temperature: f32,
     max: f32,
