@@ -8,11 +8,13 @@ use crate::{DiskUsage, Pid, ProcessExt, Signal};
 
 use std::path::Path;
 
-/// Enum describing the different status of a process.
-#[derive(Clone, Copy, Debug)]
-pub struct ProcessStatus;
+impl fmt::Display for ProcessStatus {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        f.write_str("Unknown")
+    }
+}
 
-/// Struct containing a process' information.
+#[doc = include_str!("../../md_doc/process.md")]
 #[derive(Clone)]
 pub struct Process {
     pid: Pid,
@@ -69,7 +71,7 @@ impl ProcessExt for Process {
     }
 
     fn status(&self) -> ProcessStatus {
-        ProcessStatus
+        ProcessStatus::Unknown(0)
     }
 
     fn start_time(&self) -> u64 {
