@@ -11,8 +11,10 @@
 fn test_processor() {
     use sysinfo::{NetworksExt, SystemExt};
 
-    let s = sysinfo::System::new();
-    assert_eq!(s.get_networks().iter().count(), 0);
-    let s = sysinfo::System::new_all();
-    assert!(s.get_networks().iter().count() > 0);
+    if sysinfo::System::IS_SUPPORTED {
+        let s = sysinfo::System::new();
+        assert_eq!(s.networks().iter().count(), 0);
+        let s = sysinfo::System::new_all();
+        assert!(s.networks().iter().count() > 0);
+    }
 }
